@@ -27,7 +27,6 @@ from neutron.agent.l3 import link_local_allocator as lla
 from neutron.agent.l3 import router_info
 from neutron.agent.linux import interface
 from neutron.agent.linux import ip_lib
-from neutron.common import constants as n_const
 from neutron.common import utils as common_utils
 from neutron.conf.agent import common as agent_config
 from neutron.conf.agent.l3 import config as l3_config
@@ -188,7 +187,7 @@ class TestDvrRouterOperations(base.BaseTestCase):
         self._setup_create_dvr_fip_interfaces_for_setting_routing_rules()
 
     def _setup_create_dvr_fip_interfaces_for_setting_routing_rules(
-        self, address_scopes_match=False):
+            self, address_scopes_match=False):
         ri = self._create_router()
         ri.get_floating_agent_gw_interface = mock.Mock()
         ri.fip_ns = mock.Mock()
@@ -387,7 +386,8 @@ class TestDvrRouterOperations(base.BaseTestCase):
         ri.floating_ip_removed_dist(fip_cidr)
         self.mock_delete_ip_rule.assert_called_with(
             ri.router_namespace.name, ip=fixed_ip, table=16, priority=FIP_PRI)
-        mIPDevice().route.delete_route.assert_called_with(fip_cidr, str(s.ip))
+        mIPDevice().route.delete_route.assert_called_with(fip_cidr,
+                                                          via=str(s.ip))
         ri.fip_ns.local_subnets.allocate.assert_not_called()
 
     @mock.patch.object(ip_lib, 'add_ip_rule')
@@ -650,7 +650,7 @@ class TestDvrRouterOperations(base.BaseTestCase):
         )
 
         router = l3_test_common.prepare_router_data(enable_snat=True)
-        router[n_const.FLOATINGIP_AGENT_INTF_KEY] = agent_gateway_port
+        router[lib_constants.FLOATINGIP_AGENT_INTF_KEY] = agent_gateway_port
         router['distributed'] = True
         agent = l3_agent.L3NATAgent(HOSTNAME, self.conf)
         self._set_ri_kwargs(agent, router['id'], router)
